Increase aggressiveness of the compress filter.
[paraslash.git] / sched.c
diff --git a/sched.c b/sched.c
index 2c49050cb6408085c02951b170d49d34d11169b2..873fb8e3adca7b1df2d73acd37dbf0764b74e451 100644 (file)
--- a/sched.c
+++ b/sched.c
@@ -1,24 +1,15 @@
 /*
- * Copyright (C) 2006-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2008 Andre Noll <maan@systemlinux.org>
  *
- *     This program is free software; you can redistribute it and/or modify
- *     it under the terms of the GNU General Public License as published by
- *     the Free Software Foundation; either version 2 of the License, or
- *     (at your option) any later version.
- *
- *     This program is distributed in the hope that it will be useful,
- *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- *
- *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
 /** \file sched.c paraslash's scheduling functions */
 
+#include <dirent.h> /* readdir() */
+#include <assert.h>
 #include <sys/time.h>
+
 #include "para.h"
 #include "ipc.h"
 #include "fd.h"
@@ -77,7 +68,7 @@ static void sched_post_select(struct sched *s)
  *
  * \sa task, now.
  */
-int sched(struct sched *s)
+int schedule(struct sched *s)
 {
        if (!initialized)
                return -E_NOT_INITIALIZED;
@@ -104,7 +95,7 @@ again:
  */
 static void init_sched(void)
 {
-       PARA_INFO_LOG("%s", "initializing scheduler\n");
+       PARA_INFO_LOG("initializing scheduler\n");
        INIT_LIST_HEAD(&pre_select_list);
        INIT_LIST_HEAD(&post_select_list);
        initialized = 1;
@@ -157,7 +148,7 @@ void unregister_task(struct task *t)
 /**
  * unregister all tasks
  *
* This will cause \a sched() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */
 void sched_shutdown(void)
@@ -157,7 +148,7 @@ void unregister_task(struct task *t)
  * unregister all tasks
  *
- * This will cause \a sched() to return immediately because both the
+ * This will cause \a schedule() to return immediately because both the
  * \a pre_select_list and the \a post_select_list are empty.
  */